@@ -5,11 +5,11 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     07-Oct-2019
-// Ver:      19-Oct-2019.
+// Ver:      02-Jan-2020.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2019    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2020    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -80,11 +80,10 @@ signed int aany_eq_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_s8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft == datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vceq_s8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -92,7 +91,7 @@ signed int aany_eq_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] == param1) {
 			return 1;
 		}
@@ -140,11 +139,10 @@ signed int aany_gt_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_s8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft > datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcgt_s8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -152,7 +150,7 @@ signed int aany_gt_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] > param1) {
 			return 1;
 		}
@@ -200,11 +198,10 @@ signed int aany_ge_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_s8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft >= datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcge_s8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -212,7 +209,7 @@ signed int aany_ge_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] >= param1) {
 			return 1;
 		}
@@ -260,11 +257,10 @@ signed int aany_lt_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_s8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_s8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -272,7 +268,7 @@ signed int aany_lt_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] < param1) {
 			return 1;
 		}
@@ -320,11 +316,10 @@ signed int aany_le_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_s8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft <= datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcle_s8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -332,7 +327,7 @@ signed int aany_le_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] <= param1) {
 			return 1;
 		}
@@ -380,19 +375,18 @@ signed int aany_ne_signed_char_simd(Py_ssize_t arraylen, signed char *data, sign
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_s8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft != datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vceq_s8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
-		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
+		if (vreinterpret_u64_u8(resultslice) != 0xffffffffffffffff) {
 			return 1;
 		}
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] != param1) {
 			return 1;
 		}
@@ -440,11 +434,10 @@ signed int aany_eq_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_u8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft == datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vceq_u8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -452,7 +445,7 @@ signed int aany_eq_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] == param1) {
 			return 1;
 		}
@@ -500,11 +493,10 @@ signed int aany_gt_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_u8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft > datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcgt_u8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -512,7 +504,7 @@ signed int aany_gt_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] > param1) {
 			return 1;
 		}
@@ -560,11 +552,10 @@ signed int aany_ge_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_u8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft >= datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcge_u8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -572,7 +563,7 @@ signed int aany_ge_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] >= param1) {
 			return 1;
 		}
@@ -620,11 +611,10 @@ signed int aany_lt_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_u8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_u8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -632,7 +622,7 @@ signed int aany_lt_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] < param1) {
 			return 1;
 		}
@@ -680,11 +670,10 @@ signed int aany_le_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_u8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft <= datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcle_u8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -692,7 +681,7 @@ signed int aany_le_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] <= param1) {
 			return 1;
 		}
@@ -740,19 +729,18 @@ signed int aany_ne_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data,
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		datasliceleft = vld1_u8( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft != datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vceq_u8(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
-		if (vreinterpret_u64_u8(resultslice) != 0x0000000000000000) {
+		if (vreinterpret_u64_u8(resultslice) != 0xffffffffffffffff) {
 			return 1;
 		}
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] != param1) {
 			return 1;
 		}
@@ -800,11 +788,10 @@ signed int aany_eq_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_s16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft == datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vceq_s16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -812,7 +799,7 @@ signed int aany_eq_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] == param1) {
 			return 1;
 		}
@@ -860,11 +847,10 @@ signed int aany_gt_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_s16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft > datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcgt_s16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -872,7 +858,7 @@ signed int aany_gt_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] > param1) {
 			return 1;
 		}
@@ -920,11 +906,10 @@ signed int aany_ge_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_s16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft >= datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcge_s16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -932,7 +917,7 @@ signed int aany_ge_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] >= param1) {
 			return 1;
 		}
@@ -980,11 +965,10 @@ signed int aany_lt_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_s16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_s16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -992,7 +976,7 @@ signed int aany_lt_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] < param1) {
 			return 1;
 		}
@@ -1040,11 +1024,10 @@ signed int aany_le_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_s16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft <= datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcle_s16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -1052,7 +1035,7 @@ signed int aany_le_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] <= param1) {
 			return 1;
 		}
@@ -1100,19 +1083,18 @@ signed int aany_ne_signed_short_simd(Py_ssize_t arraylen, signed short *data, si
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_s16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft != datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vceq_s16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
-		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
+		if (vreinterpret_u64_u16(resultslice) != 0xffffffffffffffff) {
 			return 1;
 		}
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] != param1) {
 			return 1;
 		}
@@ -1160,11 +1142,10 @@ signed int aany_eq_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_u16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft == datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vceq_u16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -1172,7 +1153,7 @@ signed int aany_eq_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] == param1) {
 			return 1;
 		}
@@ -1220,11 +1201,10 @@ signed int aany_gt_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_u16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft > datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcgt_u16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -1232,7 +1212,7 @@ signed int aany_gt_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] > param1) {
 			return 1;
 		}
@@ -1280,11 +1260,10 @@ signed int aany_ge_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_u16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft >= datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcge_u16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -1292,7 +1271,7 @@ signed int aany_ge_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] >= param1) {
 			return 1;
 		}
@@ -1340,11 +1319,10 @@ signed int aany_lt_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_u16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft < datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vclt_u16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -1352,7 +1330,7 @@ signed int aany_lt_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] < param1) {
 			return 1;
 		}
@@ -1400,11 +1378,10 @@ signed int aany_le_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_u16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft <= datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vcle_u16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
 		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
 			return 1;
@@ -1412,7 +1389,7 @@ signed int aany_le_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] <= param1) {
 			return 1;
 		}
@@ -1460,19 +1437,18 @@ signed int aany_ne_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		datasliceleft = vld1_u16( &data[index]);
-		// The actual SIMD operation. The compiler generates the correct SIMD
-		// operations, and stores them as a vector.
-		resultslice = datasliceleft != datasliceright;
+		// The actual SIMD operation. 
+		resultslice = vceq_u16(datasliceleft, datasliceright);
 		// Compare the results of the SIMD operation.
-		if (vreinterpret_u64_u16(resultslice) != 0x0000000000000000) {
+		if (vreinterpret_u64_u16(resultslice) != 0xffffffffffffffff) {
 			return 1;
 		}
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		if (data[index] != param1) {
 			return 1;
 		}
