@@ -507,7 +507,10 @@ _____________________________ \n\
 Calculate abs_ over the values in an array.  \n\
 \n\
 ======================  ============================================== \n\
-Equivalent to:          abs(x) \n\
+Equivalent to:          [abs(x) for x in array1] \n\
+======================  ============================================== \n\
+\n\
+======================  ============================================== \n\
 Array types supported:  b, h, i, l, q, f, d \n\
 Exceptions raised:      OverflowError \n\
 ======================  ============================================== \n\
