@@ -497,7 +497,10 @@ _____________________________ \n\
 Calculate invert over the values in an array.  \n\
 \n\
 ======================  ============================================== \n\
-Equivalent to:          ~x \n\
+Equivalent to:          [~x for x in array1] \n\
+======================  ============================================== \n\
+\n\
+======================  ============================================== \n\
 Array types supported:  b, B, h, H, i, I, l, L, q, Q \n\
 Exceptions raised:       \n\
 ======================  ============================================== \n\
