@@ -3175,7 +3175,12 @@ _____________________________ \n\
 Calculate mul over the values in an array.  \n\
 \n\
 ======================  ============================================== \n\
-Equivalent to:          x * y \n\
+Equivalent to:          [x * param for x in array1] \n\
+or                      [param * y for y in array2] \n\
+or                      [x * y for x, y in zip(array1, array2)] \n\
+======================  ============================================== \n\
+\n\
+======================  ============================================== \n\
 Array types supported:  b, B, h, H, i, I, l, L, q, Q, f, d \n\
 Exceptions raised:      OverflowError, ArithmeticError \n\
 ======================  ============================================== \n\
