@@ -507,7 +507,10 @@ _____________________________ \n\
 Calculate neg over the values in an array.  \n\
 \n\
 ======================  ============================================== \n\
-Equivalent to:          -x \n\
+Equivalent to:          [-x for x in array1] \n\
+======================  ============================================== \n\
+\n\
+======================  ============================================== \n\
 Array types supported:  b, h, i, l, q, f, d \n\
 Exceptions raised:      OverflowError, ArithmeticError \n\
 ======================  ============================================== \n\
