@@ -5,11 +5,11 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     22-Mar-2019
-// Ver:      19-Oct-2019.
+// Ver:      02-Jan-2020.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2019    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2020    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -59,6 +59,7 @@ void neg_signed_char_1_simd(Py_ssize_t arraylen, signed char *data) {
 	Py_ssize_t alignedlength;
 
 	v16qi datasliceleft;
+	v16qi vsignparam = {-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1};
 
 
 	// Calculate array lengths for arrays whose lengths which are not even
@@ -66,17 +67,17 @@ void neg_signed_char_1_simd(Py_ssize_t arraylen, signed char *data) {
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		// Load the data into the vector register.
 		datasliceleft = (v16qi) __builtin_ia32_lddqu((char *)  &data[index]);
 		// The actual SIMD operation. The compiler generates the correct instruction.
-		datasliceleft = -datasliceleft;
+		datasliceleft = __builtin_ia32_psignb128(datasliceleft, vsignparam);
 		// Store the result.
 		__builtin_ia32_storedqu((char *)  &data[index],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		data[index] = -data[index];
 	}
 
@@ -95,6 +96,7 @@ void neg_signed_char_2_simd(Py_ssize_t arraylen, signed char *data, signed char
 	Py_ssize_t alignedlength;
 
 	v16qi datasliceleft;
+	v16qi vsignparam = {-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1};
 
 
 	// Calculate array lengths for arrays whose lengths which are not even
@@ -102,17 +104,17 @@ void neg_signed_char_2_simd(Py_ssize_t arraylen, signed char *data, signed char
 	alignedlength = arraylen - (arraylen % CHARSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 		// Load the data into the vector register.
 		datasliceleft = (v16qi) __builtin_ia32_lddqu((char *)  &data[index]);
 		// The actual SIMD operation. The compiler generates the correct instruction.
-		datasliceleft = -datasliceleft;
+		datasliceleft = __builtin_ia32_psignb128(datasliceleft, vsignparam);
 		// Store the result.
 		__builtin_ia32_storedqu((char *)  &dataout[index],  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		dataout[index] = -data[index];
 	}
 
@@ -137,6 +139,7 @@ void neg_signed_short_1_simd(Py_ssize_t arraylen, signed short *data) {
 	Py_ssize_t alignedlength;
 
 	v8hi datasliceleft;
+	v8hi vsignparam = {-1, -1, -1, -1, -1, -1, -1, -1};
 
 
 	// Calculate array lengths for arrays whose lengths which are not even
@@ -144,17 +147,17 @@ void neg_signed_short_1_simd(Py_ssize_t arraylen, signed short *data) {
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
 		datasliceleft = (v8hi) __builtin_ia32_lddqu((char *)  &data[index]);
 		// The actual SIMD operation. The compiler generates the correct instruction.
-		datasliceleft = -datasliceleft;
+		datasliceleft = __builtin_ia32_psignw128(datasliceleft, vsignparam);
 		// Store the result.
 		__builtin_ia32_storedqu((char *)  &data[index], (v16qi)  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		data[index] = -data[index];
 	}
 
@@ -173,6 +176,7 @@ void neg_signed_short_2_simd(Py_ssize_t arraylen, signed short *data, signed sho
 	Py_ssize_t alignedlength;
 
 	v8hi datasliceleft;
+	v8hi vsignparam = {-1, -1, -1, -1, -1, -1, -1, -1};
 
 
 	// Calculate array lengths for arrays whose lengths which are not even
@@ -180,17 +184,17 @@ void neg_signed_short_2_simd(Py_ssize_t arraylen, signed short *data, signed sho
 	alignedlength = arraylen - (arraylen % SHORTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 		// Load the data into the vector register.
 		datasliceleft = (v8hi) __builtin_ia32_lddqu((char *)  &data[index]);
 		// The actual SIMD operation. The compiler generates the correct instruction.
-		datasliceleft = -datasliceleft;
+		datasliceleft = __builtin_ia32_psignw128(datasliceleft, vsignparam);
 		// Store the result.
 		__builtin_ia32_storedqu((char *)  &dataout[index], (v16qi)  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		dataout[index] = -data[index];
 	}
 
@@ -215,6 +219,7 @@ void neg_signed_int_1_simd(Py_ssize_t arraylen, signed int *data) {
 	Py_ssize_t alignedlength;
 
 	v4si datasliceleft;
+	v4si vsignparam = {-1, -1, -1, -1};
 
 
 	// Calculate array lengths for arrays whose lengths which are not even
@@ -222,17 +227,17 @@ void neg_signed_int_1_simd(Py_ssize_t arraylen, signed int *data) {
 	alignedlength = arraylen - (arraylen % INTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += INTSIMDSIZE) {
 		// Load the data into the vector register.
 		datasliceleft = (v4si) __builtin_ia32_lddqu((char *)  &data[index]);
 		// The actual SIMD operation. The compiler generates the correct instruction.
-		datasliceleft = -datasliceleft;
+		datasliceleft = __builtin_ia32_psignd128(datasliceleft, vsignparam);
 		// Store the result.
 		__builtin_ia32_storedqu((char *)  &data[index], (v16qi)  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		data[index] = -data[index];
 	}
 
@@ -251,6 +256,7 @@ void neg_signed_int_2_simd(Py_ssize_t arraylen, signed int *data, signed int *da
 	Py_ssize_t alignedlength;
 
 	v4si datasliceleft;
+	v4si vsignparam = {-1, -1, -1, -1};
 
 
 	// Calculate array lengths for arrays whose lengths which are not even
@@ -258,17 +264,17 @@ void neg_signed_int_2_simd(Py_ssize_t arraylen, signed int *data, signed int *da
 	alignedlength = arraylen - (arraylen % INTSIMDSIZE);
 
 	// Perform the main operation using SIMD instructions.
-	for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
+	for (index = 0; index < alignedlength; index += INTSIMDSIZE) {
 		// Load the data into the vector register.
 		datasliceleft = (v4si) __builtin_ia32_lddqu((char *)  &data[index]);
 		// The actual SIMD operation. The compiler generates the correct instruction.
-		datasliceleft = -datasliceleft;
+		datasliceleft = __builtin_ia32_psignd128(datasliceleft, vsignparam);
 		// Store the result.
 		__builtin_ia32_storedqu((char *)  &dataout[index], (v16qi)  datasliceleft);
 	}
 
 	// Get the max value within the left over elements at the end of the array.
-	for(index = alignedlength; index < arraylen; index++) {
+	for (index = alignedlength; index < arraylen; index++) {
 		dataout[index] = -data[index];
 	}
 
