@@ -231,7 +231,7 @@ _____________________________ \n\
 Calculate sqrt over the values in an array.  \n\
 \n\
 ======================  ============================================== \n\
-Equivalent to:          math.sqrt(x) \n\
+Equivalent to:          [math.sqrt(x) for x in array1] \n\
 Array types supported:  f, d \n\
 Exceptions raised:      ArithmeticError \n\
 ======================  ============================================== \n\
